@@ -24,6 +24,7 @@
 
 #include <vector>
 
+#include <QHostAddress>
 #include <QObject>
 #include <QStringList>
 #include <QSignalMapper>
@@ -39,6 +40,12 @@ class SyLwrpServer : public QObject
   Q_OBJECT
  public:
   SyLwrpServer(SyRouting *routing);
+  void sendGpiState(int slot,const QString &code);
+  void sendGpoState(int slot,const QString &code);
+
+ signals:
+  void gpoCfgChanged(int slot,SyRouting::GpoMode mode,
+		     const QHostAddress &addr,int snake_slot);
 
  private slots:
   void newConnectionData();
@@ -54,10 +61,14 @@ class SyLwrpServer : public QObject
   bool ExecuteGpi(int ch,QStringList &args);
   bool ExecuteGpo(int ch,QStringList &args);
   bool ExecuteIfc(int ch,QStringList &args);
+  bool ExecuteCfg(int ch,QStringList &args);
+  bool ExecuteAdd(int ch,QStringList &args);
+  bool ExecuteDel(int ch,QStringList &args);
   QString SrcLine(int slot);
   QString DstLine(int slot);
   QString GpiLine(int slot);
   QString GpoLine(int slot);
+  QString CfgLine(int slot);
   QStringList ParseField(const SyAString &field);
   void ParseCommand(int id);
   void BroadcastCommand(const QString &cmd);
